@@ -230,3 +230,24 @@ def test_requires_scope(mocker):
     assert not auth.requires_scope('somethingnotthere')
     mock_jwt.get_unverified_claims.return_value = {}
     assert not auth.requires_scope('foo')
+
+def test_requires_permission(mocker):
+    """
+    - Return True if the permission is in the list of token permissions
+    - Return False otherwise
+    """
+    mock_token = 'sometokenstring'
+    mock_get_token = mocker.patch('busie_flask.auth.AuthHelper.get_token_auth_header')
+    mock_get_token.return_value = mock_token
+    mock_jwt = mocker.patch('busie_flask.auth.jwt')
+    mock_unverified_claims = {'permissions': ['some:perm', 'someother:perm']}
+    mock_jwt.get_unverified_claims.return_value = mock_unverified_claims
+
+    auth = AuthHelper()
+    assert auth.requires_permission(mock_unverified_claims['permissions'][0])
+    mock_get_token.assert_called_once()
+    mock_jwt.get_unverified_claims.assert_called_once_with(mock_token)
+    
+    assert not auth.requires_permission('something:invalid')
+    mock_jwt.get_unverified_claims.return_value = {}
+    assert not auth.requires_permission(mock_unverified_claims['permissions'][0])
\ No newline at end of file
